# ChiTuBox Network Manager

Tool to interact with the ChiTuBoard based networked LCD Resin printer

```
usage: chitucli [-h] --ip IP
                [--list | --query | --axis-z | --version | --print | --upload | --download]
                [files [files ...]]

positional arguments:
  files

optional arguments:
  -h, --help      show this help message and exit
  --ip IP, -i IP
  --list, -L
  --query, -Q
  --axis-z, -Z
  --version, -V
  --print, -P
  --upload, -U
  --download, -D
```
